==> owncloud-8.2.2-2-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/activity/l10n/bg_BG.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "Активност",
    "Personal activity feed for %s" : "Личен поток за активност на %s.",
    "Your feed URL is invalid" : "Потока е с невалиден адрес",
    "Your settings have been updated." : "Вашите настройки са актуализирани.",
    "Mail" : "Поща",
    "Stream" : "Поток",
    "This stream will show events like additions, changes & shares" : "Потокът ще покаже събития като допълнения, изменения и споделяния",
    "There are no events for this filter" : "Няма събития за този филтър",
    "Activity notification" : "Известия за активност",
    "All Activities" : "Активност на всички",
    "Activities by you" : "Вашата активност",
    "Activities by others" : "Активността на другите",
    "\"remote user\"" : "\"отдалечен потребител\"",
    "in %s" : "в %s",
    "%s and %s" : "%s и %s",
    ", " : ", ",
    "_%s and %n more_::_%s and %n more_" : ["%s и %n друга","%s и още %n"],
    "Hello %s," : "Здравей %s,",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* и %n още","* и %n още "],
    "Notifications" : "Известия",
    "List your own actions in the stream" : "Показване на собствените действия в потока",
    "Notify about your own actions via email" : "Уведомяване за собствени действия чрез електронна поща",
    "You need to set up your email address before you can receive notification emails." : "Първо трябва да настроите вашия имейл адрес, преди да започнете да получавате известия.",
    "Send emails:" : "Изпращане на имейли:",
    "Hourly" : "На всеки час",
    "Daily" : "Ежедневно",
    "Weekly" : "Седмично",
    "Activity feed" : "Поток за активност",
    "Enable RSS feed" : "Разрешаване на RSS източници.",
    "No activity yet" : "Няма активност все още",
    "No more events to load" : "Няма повече известия за зареждане.",
    "Files" : "Файлове"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-9.1.3-2-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/activity/l10n/bg_BG.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "Активност",
    "Activities" : "Актнивности",
    "Error loading activities" : "Грешка при зареждане на активностите",
    "No activities" : "Няма активност",
    "Load more activities" : "Зареди повече активности",
    ", " : ", ",
    "{parameterList} and {lastParameter}" : "{parameterList} и {lastParameter}",
    "in {directory}" : "в {directory}",
    "This stream will show events like additions, changes & shares" : "Потокът ще покаже събития като допълнения, изменения и споделяния",
    "There are no events for this filter" : "Няма събития за този филтър",
    "Today" : "Днес",
    "Yesterday" : "Вчера",
    "Personal activity feed for %s" : "Личен поток за активност на %s.",
    "Your feed URL is invalid" : "Потока е с невалиден адрес",
    "Your settings have been updated." : "Вашите настройки са актуализирани.",
    "Mail" : "Поща",
    "Stream" : "Поток",
    "\"remote user\"" : "\"отдалечен потребител\"",
    "Activity notification" : "Известия за активност",
    "All Activities" : "Активност на всички",
    "Activities by you" : "Вашата активност",
    "Activities by others" : "Активността на другите",
    "%s and %s" : "%s и %s",
    "Hello %s," : "Здравей %s,",
    "You are receiving this email because the following things happened at %s" : "Получавате този имейл, защото се случиха следните неща в %s",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* и %n още","* и %n още "],
    "List your own file actions in the stream" : "Списък на вашите собствени файлове действия в потока",
    "Notify about your own actions via email" : "Уведомяване за собствени действия чрез електронна поща",
    "You need to set up your email address before you can receive notification emails." : "Първо трябва да настроите вашия имейл адрес, преди да започнете да получавате известия.",
    "Send emails:" : "Изпращане на имейли:",
    "Hourly" : "На всеки час",
    "Daily" : "Ежедневно",
    "Weekly" : "Седмично",
    "Activity feed" : "Поток за активност",
    "Enable RSS feed" : "Разрешаване на RSS източници.",
    "No activity yet" : "Няма активност все още",
    "No more events to load" : "Няма повече известия за зареждане.",
    "Files" : "Файлове"
},
"nplurals=2; plural=(n != 1);");
